# SDL::Constants
#
# This is an automatically generated file, don't bother editing
#
# Copyright (C) 2003 David J. Goehrig <dave@sdlperl.org>
#

package SDL::Constants;


sub main::SDLK_INSERT { 277 }
sub main::SDL_INIT_VIDEO { 32 }
sub main::SDLK_AMPERSAND { 38 }
sub main::SDL_AUDIO_PAUSED { 2 }
sub main::UNICODE_BLENDED { 256 }
sub main::SDLK_COMMA { 44 }
sub main::KMOD_LSHIFT { 1 }
sub main::SDLK_LSUPER { 311 }
sub main::SDLK_EURO { 321 }
sub main::SDL_JOYAXISMOTION { 7 }
sub main::SDL_PRESSED { 1 }
sub main::SDL_DOUBLEBUF { 1073741824 }
sub main::SDL_GL_ACCUM_BLUE_SIZE { 10 }
sub main::KMOD_SHIFT { 3 }
sub main::SDLK_QUOTE { 39 }
sub main::SDLK_a { 97 }
sub main::SDL_AUDIO_STOPPED { 0 }
sub main::SDLK_b { 98 }
sub main::SDLK_c { 99 }
sub main::SDLK_d { 100 }
sub main::SDLK_e { 101 }
sub main::SMPEG_PLAYING { 1 }
sub main::SDL_GRAB_ON { 1 }
sub main::SDLK_f { 102 }
sub main::SDLK_g { 103 }
sub main::SDLK_h { 104 }
sub main::SDL_HAT_RIGHT { 2 }
sub main::SDLK_i { 105 }
sub main::SDLK_j { 106 }
sub main::SDLK_PERIOD { 46 }
sub main::SDL_HWPALETTE { 536870912 }
sub main::SDLK_k { 107 }
sub main::SDLK_l { 108 }
sub main::TEXT_SHADED { 2 }
sub main::SDLK_m { 109 }
sub main::SDLK_n { 110 }
sub main::SDLK_o { 111 }
sub main::SDLK_p { 112 }
sub main::SDLK_q { 113 }
sub main::SDLK_r { 114 }
sub main::SDL_MOUSEMOTION { 4 }
sub main::SDLK_s { 115 }
sub main::SDLK_t { 116 }
sub main::SDL_RELEASED { 0 }
sub main::SDL_GL_BLUE_SIZE { 2 }
sub main::SDLK_u { 117 }
sub main::SDLK_v { 118 }
sub main::SDLK_w { 119 }
sub main::SDLK_x { 120 }
sub main::SDLK_SYSREQ { 317 }
sub main::SDLK_y { 121 }
sub main::SDLK_z { 122 }
sub main::SDLK_SLASH { 47 }
sub main::SDLK_ASTERISK { 42 }
sub main::KMOD_NONE { 0 }
sub main::SDLK_CARET { 94 }
sub main::CD_ERROR { -1 }
sub main::SDLK_UNDERSCORE { 95 }
sub main::SDL_PREALLOC { 16777216 }
sub main::KMOD_CTRL { 192 }
sub main::MIX_NO_FADING { 0 }
sub main::SDLK_QUESTION { 63 }
sub main::SDL_QUERY { -1 }
sub main::SDL_IYUV_OVERLAY { 1448433993 }
sub main::SDLK_BREAK { 318 }
sub main::SDL_APPINPUTFOCUS { 2 }
sub main::SDLK_LEFTBRACKET { 91 }
sub main::SDL_ACTIVEEVENT { 1 }
sub main::TTF_STYLE_ITALIC { 2 }
sub main::SMPEG_ERROR { -1 }
sub main::SDLK_KP_DIVIDE { 267 }
sub main::SDL_FULLSCREEN { -2147483648 }
sub main::SDL_HAT_CENTERED { 0 }
sub main::SDL_GL_ACCUM_GREEN_SIZE { 9 }
sub main::SDL_YVYU_OVERLAY { 1431918169 }
sub main::SDL_JOYBUTTONUP { 11 }
sub main::SDLK_GREATER { 62 }
sub main::AUDIO_U16MSB { 4112 }
sub main::AUDIO_U16 { 16 }
sub main::SDLK_RETURN { 13 }
sub main::SDLK_KP_PERIOD { 266 }
sub main::SDLK_BACKSPACE { 8 }
sub main::SDL_ANYFORMAT { 268435456 }
sub main::SDL_ENABLE { 1 }
sub main::SDL_KEYUP { 3 }
sub main::SDL_AUDIO_PLAYING { 1 }
sub main::SDL_HAT_RIGHTDOWN { 6 }
sub main::SDLK_ESCAPE { 27 }
sub main::SDL_GL_ALPHA_SIZE { 3 }
sub main::SDL_ASYNCBLIT { 4 }
sub main::MIX_DEFAULT_FREQUENCY { 22050 }
sub main::MIX_DEFAULT_CHANNELS { 2 }
sub main::SDLK_LEFTPAREN { 40 }
sub main::SDL_GRAB_OFF { 0 }
sub main::KMOD_CAPS { 8192 }
sub main::UTF8_BLENDED { 32 }
sub main::SDL_MOUSEBUTTONUP { 6 }
sub main::SDL_BUTTON_WHEELUP  { 4 }
sub main::SDL_BUTTON_WHEELDOWN { 5 }
sub main::SDLK_HASH { 35 }
sub main::SDL_HAT_RIGHTUP { 3 }
sub main::SDL_SWSURFACE { 0 }
sub main::AUDIO_S16MSB { 36880 }
sub main::SDL_INIT_CDROM { 256 }
sub main::SDL_HAT_UP { 1 }
sub main::SDL_INIT_EVERYTHING { 65535 }
sub main::SDLK_DOLLAR { 36 }
sub main::KMOD_RCTRL { 128 }
sub main::SDLK_RIGHTBRACKET { 93 }
sub main::SDL_YUY2_OVERLAY { 844715353 }
sub main::SDL_HWSURFACE { 1 }
sub main::SDL_HWACCEL { 256 }
sub main::SDLK_AT { 64 }
sub main::SDL_GL_STENCIL_SIZE { 7 }
sub main::SDLK_KP_PLUS { 270 }
sub main::SDLK_LALT { 308 }
sub main::SDLK_PAGEDOWN { 281 }
sub main::SDL_INIT_TIMER { 1 }
sub main::SDLK_RSHIFT { 303 }
sub main::CD_STOPPED { 1 }
sub main::SDL_KEYDOWN { 2 }
sub main::INADDR_ANY { 0 }
sub main::SDL_GL_DEPTH_SIZE { 6 }
sub main::CD_PAUSED { 3 }
sub main::SDL_OPENGLBLIT { 10 }
sub main::SDLK_END { 279 }
sub main::SDL_INIT_AUDIO { 16 }
sub main::SDL_MOUSEBUTTONDOWN { 5 }
sub main::SDL_IGNORE { 0 }
sub main::KMOD_LALT { 256 }
sub main::SDLK_KP_MULTIPLY { 268 }
sub main::SDLK_RIGHTPAREN { 41 }
sub main::SDL_INIT_NOPARACHUTE { 1048576 }
sub main::SDLK_CLEAR { 12 }
sub main::SDLK_TAB { 9 }
sub main::MIX_FADING_OUT { 1 }
sub main::SDL_MIX_MAXVOLUME { 128 }
sub main::SDL_SRCCOLORKEY { 4096 }
sub main::SDLK_SPACE { 32 }
sub main::SDLK_NUMLOCK { 300 }
sub main::SDL_OPENGL { 2 }
sub main::UNICODE_SHADED { 128 }
sub main::SDL_YV12_OVERLAY { 842094169 }
sub main::KMOD_LCTRL { 64 }
sub main::SDL_UYVY_OVERLAY { 1498831189 }
sub main::AUDIO_S8 { 32776 }
sub main::SDL_JOYBUTTONDOWN { 10 }
sub main::SDLK_RCTRL { 305 }
sub main::SDL_QUIT { 12 }
sub main::MIX_DEFAULT_FORMAT { 32784 }
sub main::SDLK_CAPSLOCK { 301 }
sub main::INADDR_NONE { -1 }
sub main::SDLK_HOME { 278 }
sub main::SDLK_SEMICOLON { 59 }
sub main::MIX_FADING_IN { 2 }
sub main::CD_TRAYEMPTY { 0 }
sub main::SDLK_EQUALS { 61 }
sub main::SDLK_RMETA { 309 }
sub main::SDLK_HELP { 315 }
sub main::SDLK_LESS { 60 }
sub main::SDL_GL_ACCUM_RED_SIZE { 8 }
sub main::SDL_GL_RED_SIZE { 0 }
sub main::SDLK_POWER { 320 }
sub main::SDLK_F1 { 282 }
sub main::CD_PLAYING { 2 }
sub main::SDLK_F2 { 283 }
sub main::SDL_GL_ACCUM_ALPHA_SIZE { 11 }
sub main::SDLK_F3 { 284 }
sub main::SDLK_F4 { 285 }
sub main::SDLK_F5 { 286 }
sub main::SDLK_PLUS { 43 }
sub main::TTF_STYLE_BOLD { 1 }
sub main::SDLK_F6 { 287 }
sub main::SDL_RLEACCELOK { 8192 }
sub main::SDLK_F7 { 288 }
sub main::SDLK_F8 { 289 }
sub main::SDLK_F9 { 290 }
sub main::SDLK_QUOTEDBL { 34 }
sub main::KMOD_RSHIFT { 2 }
sub main::SDLK_RSUPER { 312 }
sub main::SDL_JOYBALLMOTION { 8 }
sub main::SDL_APPMOUSEFOCUS { 1 }
sub main::SDLK_PRINT { 316 }
sub main::SDLK_F10 { 291 }
sub main::SDLK_F11 { 292 }
sub main::SDLK_MENU { 319 }
sub main::SDLK_F12 { 293 }
sub main::SDLK_F13 { 294 }
sub main::SDLK_F14 { 295 }
sub main::SDLK_RALT { 307 }
sub main::SDLK_F15 { 296 }
sub main::AUDIO_U8 { 8 }
sub main::SDLK_UP { 273 }
sub main::UTF8_SHADED { 16 }
sub main::SDLK_LSHIFT { 304 }
sub main::SDLK_KP0 { 256 }
sub main::SDLK_BACKQUOTE { 96 }
sub main::SDLK_KP1 { 257 }
sub main::SDLK_KP2 { 258 }
sub main::SDLK_KP3 { 259 }
sub main::SDLK_KP4 { 260 }
sub main::SDLK_KP5 { 261 }
sub main::SDLK_RIGHT { 275 }
sub main::SDLK_KP6 { 262 }
sub main::SDLK_KP7 { 263 }
sub main::SDLK_KP8 { 264 }
sub main::SDLK_KP9 { 265 }
sub main::SDL_HAT_LEFTDOWN { 12 }
sub main::SDL_SYSWMEVENT { 13 }
sub main::TEXT_BLENDED { 4 }
sub main::SDL_GL_BUFFER_SIZE { 4 }
sub main::SDLK_SCROLLOCK { 302 }
sub main::SDLK_DOWN { 274 }
sub main::SDLK_MINUS { 45 }
sub main::SDLK_BACKSLASH { 92 }
sub main::SDL_HAT_DOWN { 4 }
sub main::SDLK_LEFT { 276 }
sub main::SMPEG_STOPPED { 0 }
sub main::SDLK_EXCLAIM { 33 }
sub main::KMOD_RALT { 512 }
sub main::SDL_GL_GREEN_SIZE { 1 }
sub main::SDLK_LCTRL { 306 }
sub main::SDL_GL_DOUBLEBUFFER { 5 }
sub main::SDL_HAT_LEFT { 8 }
sub main::SDL_SRCALPHA { 65536 }
sub main::SDLK_PAUSE { 19 }
sub main::KMOD_ALT { 768 }
sub main::MIX_MAX_VOLUME { 128 }
sub main::UTF8_SOLID { 8 }
sub main::SDL_HAT_LEFTUP { 9 }
sub main::SDLK_LMETA { 310 }
sub main::SDL_APPACTIVE { 4 }
sub main::SDL_RLEACCEL { 16384 }
sub main::SDL_RESIZABLE { 16 }
sub main::AUDIO_S16 { 32784 }
sub main::SDLK_KP_EQUALS { 272 }
sub main::SDL_JOYHATMOTION { 9 }
sub main::UNICODE_SOLID { 64 }
sub main::SDL_GRAB_QUERY { -1 }
sub main::SDLK_KP_ENTER { 271 }
sub main::SDL_INIT_JOYSTICK { 512 }
sub main::TEXT_SOLID { 1 }
sub main::SDLK_DELETE { 127 }
sub main::TTF_STYLE_UNDERLINE { 4 }
sub main::SDL_VIDEORESIZE { 16 }
sub main::KMOD_NUM { 4096 }
sub main::SDLK_0 { 48 }
sub main::SDLK_1 { 49 }
sub main::SDLK_2 { 50 }
sub main::SDLK_3 { 51 }
sub main::SDLK_4 { 52 }
sub main::SDLK_5 { 53 }
sub main::SDLK_6 { 54 }
sub main::SDLK_PAGEUP { 280 }
sub main::SDLK_7 { 55 }
sub main::SDLK_8 { 56 }
sub main::SDLK_9 { 57 }
sub main::SDLK_COLON { 58 }
sub main::SDLK_KP_MINUS { 269 }
sub main::TTF_STYLE_NORMAL { 0 }
sub main::SDLK_MODE { 313 }


1;

